add_sample_name: Add sample namel

Description Usage Arguments Value Author(s)

View source: R/add_sample_name.R

Description

Append a column with the sample name.

Usage

1

Arguments

data

dataframe containing the variant data (required)

sample

name of the sample to append to the dataframe (required)

Value

Returns a dataframe with the sample name appended as a separate column labelled "sample".

Author(s)

Richard J. de Borja


Bio-Core/BioCore.Annotation documentation built on Feb. 3, 2020, 6:01 p.m.