filter_on_population: Filter on population data.

Description Usage Arguments Value Author(s)

View source: R/filter_on_population.R

Description

A function for filtering variants on common population database occurrence.

Usage

1
filter_on_population(data = NULL, exac_threshold = 0.01, g1000_threshold = 0.01, esp_threshold = 0.01, exac="ExAC_ALL", g1000="X1000G_ALL", esp="ESP6500siv2_ALL")

Arguments

data

dataframe containing variant data (required)

exac_threshold

maximum ExAC threshold (default: 0.01)

g1000_threshold

maximum 1000 Genomes threshold (default: 0.01)

esp_threshold

maximum Exome Server Project threshold (default: 0.01)

Value

Returns the variant dataframe with mutations that exceed the maximum threshold removed.

Author(s)

Richard J. de Borja


Bio-Core/BioCore.Annotation documentation built on Feb. 3, 2020, 6:01 p.m.