Description Usage Arguments Value Author(s)
View source: R/get_coding_mutations.R
A function that parses a variant database and filters any mutation that is a synonymous SNV, unknown, intergenic or an empty string.
1 | get_coding_mutations(data = NULL, filters = c("synonymous SNV", "unknown", "intergenic", ""))
|
data |
a dataframe containing variants (required) |
filters |
a list of functional consequence types to filter (default: "synonymous SNV", "unknown", "intergenic", "") |
Returns a dataframe with variants classified as "synonymous SNV", "unknown", "intergenic", or "" removed.
Richard J. de Borja
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.