Description Usage Arguments Value Author(s)
View source: R/add_sample_name.R
Append a column with the sample name.
1 | add_sample_name(data = NULL, sample = NULL)
|
data |
dataframe containing the variant data (required) |
sample |
name of the sample to append to the dataframe (required) |
Returns a dataframe with the sample name appended as a separate column labelled "sample".
Richard J. de Borja
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.